/**
 * This file is part of the PNML Tool project. The Universal PNML Tool is a tool that can be used for creating and modifying all kinds of Petri nets and for exporting them in PNML syntax. 
 * Copyright (C) 2009 YoujunHu, s061331@student.dtu.dk
 *  
 * PNML Tool is free software; you can redistribute it and/or modify it under the terms of the Eclipse Public License as published by Eclipse Foundation;version 1 of the License.
 * PNML Tool is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  Eclipse Public License for more details.
 * You should have received a copy of the Eclipse Public License along with PNML Tool, if not, write to the Eclipse Foundation, Inc.102 Centrepointe Drive Ottawa, Ontario, Canada, K2G 6B1 
 *
 * $Id$
 */
package org.pnml.tools.epnk.diagram.notationtransfer;

import org.eclipse.core.runtime.Status;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.impl.ENotificationImpl;
import org.eclipse.emf.ecore.util.EContentAdapter;
import org.eclipse.emf.transaction.NotificationFilter;
import org.eclipse.gmf.runtime.notation.Bounds;
import org.eclipse.gmf.runtime.notation.Edge;
import org.eclipse.gmf.runtime.notation.LayoutConstraint;
import org.eclipse.gmf.runtime.notation.Location;
import org.eclipse.gmf.runtime.notation.NotationPackage;
import org.eclipse.gmf.runtime.notation.RelativeBendpoints;
import org.eclipse.gmf.runtime.notation.Size;
import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.gmf.runtime.notation.datatype.RelativeBendpoint;
import org.pnml.tools.epnk.diagram.part.PNMLCoreModelDiagramEditorPlugin;
import org.pnml.tools.epnk.pnmlcoremodel.AnnotationGraphics;
import org.pnml.tools.epnk.pnmlcoremodel.Arc;
import org.pnml.tools.epnk.pnmlcoremodel.ArcGraphics;
import org.pnml.tools.epnk.pnmlcoremodel.Coordinate;
import org.pnml.tools.epnk.pnmlcoremodel.Label;
import org.pnml.tools.epnk.pnmlcoremodel.LabelProxy;
import org.pnml.tools.epnk.pnmlcoremodel.Node;
import org.pnml.tools.epnk.pnmlcoremodel.NodeGraphics;
import org.pnml.tools.epnk.pnmlcoremodel.Object;
import org.pnml.tools.epnk.pnmlcoremodel.Page;
import org.pnml.tools.epnk.pnmlcoremodel.PageLabelProxy;
import org.pnml.tools.epnk.pnmlcoremodel.PnmlcoremodelFactory;



/**
 * The class updates Petri net graphics when the GMF diagram is changed. 
 * @generated NOT
 * @authors Lukasz, Youjun, eki
 */
public class GraphicElementListener extends EContentAdapter {

	private NotificationFilter ModifiedFilter;

	public GraphicElementListener() {
		ModifiedFilter = NotificationFilter.createEventTypeFilter(
				Notification.SET).or(
				NotificationFilter.createEventTypeFilter(Notification.UNSET))
				.or(NotificationFilter.createEventTypeFilter(
				Notification.ADD)).
				or(NotificationFilter.createEventTypeFilter(
						Notification.REMOVE));
	}

	public void notifyChanged(Notification notification) {
		if (notification.getNotifier() instanceof EObject) {
			super.notifyChanged(notification);
		}
		if (ModifiedFilter.matches(notification)
				&& (notification instanceof ENotificationImpl)
				&& (notification.getNotifier() instanceof EObject)
				) {
			
			ENotificationImpl eNotification = (ENotificationImpl) notification;
			EObject eNotifier = (EObject) eNotification.getNotifier();

			if (NotationPackage.eINSTANCE.getLocation().isSuperTypeOf(
					eNotifier.eClass())) {
				updateNodeBounds(eNotification, eNotifier);
				// eki: not used for now
			    //updateLabelPosition(eNotification, eNotifier);
			}
			/* else if (NotationPackage.eINSTANCE.getLocation().isSuperTypeOf(
					eNotifier.eClass())){ */
			/* else if (NotationPackage.eINSTANCE.getLayoutConstraint().isSuperTypeOf(
					eNotifier.eClass())){
				// eki: not used for now
				// updateLabelPosition(eNotification, eNotifier); 
			} */
			  else if (eNotifier instanceof RelativeBendpoints) {
				// Deal with bendpoints of arcs
				EObject object = eNotifier.eContainer();
				if (object instanceof Edge) {
					Edge edge = (Edge) object;
					object = edge.getElement();
					if (object != null && object instanceof Arc) {
						Arc arc = (Arc) object;
						// FIXME could be more defensive
						ArcGraphics arcGraphics = (ArcGraphics) arc.getGraphics();
						if (arcGraphics == null) {
							arcGraphics = PnmlcoremodelFactory.eINSTANCE.createArcGraphics();
							arc.setGraphics(arcGraphics);
						}
						
						arcGraphics.getPosition().clear();
						int x = 0;
						int y = 0;
						Node source = arc.getSource();
						if (source != null) {
							// FIXME should be more defensive
							NodeGraphics nodeGraphics = (NodeGraphics) source.getGraphics();
							if (nodeGraphics != null) {
								x = (int) nodeGraphics.getPosition().getX();
								y = (int) nodeGraphics.getPosition().getY();
							}
						}
						
						for (java.lang.Object pointObj: ((RelativeBendpoints) eNotifier).getPoints() ) {
						// FIXME should be more defensive
							if (pointObj instanceof RelativeBendpoint) {
								RelativeBendpoint point = (RelativeBendpoint) pointObj;
								Coordinate coord = PnmlcoremodelFactory.eINSTANCE.createCoordinate();
								coord.setX(x + point.getSourceX());
								coord.setY(y + point.getSourceY());
								arcGraphics.getPosition().add(coord);
							}
						}
					}
				}
			}
		}
	}

	/* eki: not used for now
	private void updateLabelPosition(ENotificationImpl eNotification,
			EObject eNotifier) {
		int featureID = eNotification.getFeatureID(EAttribute.class);
		EObject modelElement = ((View) eNotifier.eContainer()).getElement();
        

		if (modelElement instanceof Annotation) {
			Annotation annotation = (Annotation) modelElement;
			
			if (annotation.getGraphics() == null){
				AnnotationGraphics annotGraphics = PnmlFactoryImpl.eINSTANCE.createAnnotationGraphics();
				annotation.setGraphics(annotGraphics);
			}
			
			Offset newOffset = PnmlFactoryImpl.eINSTANCE
			.createOffset();

			
			if (annotation.getGraphics().getOffset() == null){
				annotation.getGraphics().setOffset(newOffset);
			}
						
			switch (featureID) {
			case NotationPackage.LOCATION__X:
				newOffset.setX(eNotification.getNewIntValue());
				newOffset.setY(annotation.getGraphics()
						.getOffset().getY());
				annotation.getGraphics().setOffset(newOffset);				
				break;

			case NotationPackage.LOCATION__Y:
				newOffset.setX(annotation.getGraphics()
						.getOffset().getX());
				newOffset.setY(eNotification.getNewIntValue());
				annotation.getGraphics().setOffset(newOffset);
				break;
			}
			
		}
		
	}
    */

	
	private void updateNodeBounds(ENotificationImpl eNotification,
			EObject eNotifier) {

		// int featureID = eNotification.getFeatureID(EAttribute.class);
		View view = (View) eNotifier.eContainer();
		EObject modelElement = view.getElement();

		if (modelElement instanceof Node || modelElement instanceof Page){
			Object modelNode = (Object) modelElement;
			 
			NodeGraphics nodeGraphics = (NodeGraphics) modelNode.getGraphics();
			if (nodeGraphics == null){
				nodeGraphics = PnmlcoremodelFactory.eINSTANCE.createNodeGraphics();
				modelNode.setGraphics(nodeGraphics);
			}
			
			// TODO needs to be more defensive
			Coordinate newPosition = getNodePosition((org.eclipse.gmf.runtime.notation.Node) view);
			nodeGraphics.setPosition(newPosition);

			Coordinate newDimension = getNodeDimension((org.eclipse.gmf.runtime.notation.Node) view);
			nodeGraphics.setDimension(newDimension);
			
			// TODO the labels attached to this node also need to be updated too, since their positions
			//       are relative to this position!
		} else if (modelElement instanceof LabelProxy) {
			LabelProxy labelProxy = (LabelProxy) modelElement;
			Label label = labelProxy.getLabel();
					 
			if (label != null) {
				AnnotationGraphics labelGraphics = (AnnotationGraphics) label.getGraphics();
				if (labelGraphics == null){
					labelGraphics = PnmlcoremodelFactory.eINSTANCE.createAnnotationGraphics();
					label.setGraphics(labelGraphics);
				}

				// TODO needs to be more defensive
				Coordinate newPosition = getLabelOffset((Object) label.eContainer(), (org.eclipse.gmf.runtime.notation.Node) view);
				labelGraphics.setOffset(newPosition);
			}
		} else if (modelElement instanceof PageLabelProxy) {
			PageLabelProxy pageLabelProxy = (PageLabelProxy) modelElement;
			Label label = pageLabelProxy.getLabel();
					 
			if (label != null) {
				AnnotationGraphics labelGraphics = (AnnotationGraphics) label.getGraphics();
				if (labelGraphics == null){
					labelGraphics = PnmlcoremodelFactory.eINSTANCE.createAnnotationGraphics();
					label.setGraphics(labelGraphics);
				}

				// TODO needs to be more defensive
				Coordinate newPosition = getAbsolutePNMLPosition((org.eclipse.gmf.runtime.notation.Node) view);
				labelGraphics.setOffset(newPosition);
			}
		} else {
			Status status = new Status(Status.ERROR, 
					PNMLCoreModelDiagramEditorPlugin.ID, 
					Status.OK, 
					"Undealt case in graphics update: should not happen!", 
					new Exception());
			PNMLCoreModelDiagramEditorPlugin.getInstance().getLog().log(status);
		}
	}
	
	private static Coordinate getNodePosition(org.eclipse.gmf.runtime.notation.Node node) {
		Coordinate coord = PnmlcoremodelFactory.eINSTANCE.createCoordinate();

		LayoutConstraint layout = node.getLayoutConstraint();
		if (layout != null) {
			if (layout instanceof Bounds) {
				Bounds bounds = (Bounds) layout;
				// Transform from upper left corner to center
				coord.setX(bounds.getX()+bounds.getWidth()/2.0f);
				coord.setY(bounds.getY()+bounds.getHeight()/2.0f);
			} else if (layout instanceof Location) {
				// Transform from upper left corner to center
                // with GMF standard with (40)
				Location location = (Location) layout;
				coord.setX(location.getX()+20.0f);
				coord.setY(location.getY()+20.0f);
			}
		}

		return coord;
	}
	
	private static Coordinate getNodeDimension(org.eclipse.gmf.runtime.notation.Node node) {
		Coordinate coord = PnmlcoremodelFactory.eINSTANCE.createCoordinate();

		LayoutConstraint layout = node.getLayoutConstraint();
		if (layout != null) {
			if (layout instanceof Size) {
				Size size = (Size) layout;
				int width=size.getWidth();
				if (width <0) width = 40;
				coord.setX(width);
				int height = size.getHeight();
				if (height<0) height=40;
				coord.setY(height);
			} 
		}

		return coord;
	}
	
	private static Coordinate getLabelOffset(Object object, org.eclipse.gmf.runtime.notation.Node node) {
		Coordinate coord = PnmlcoremodelFactory.eINSTANCE.createCoordinate();

		LayoutConstraint layout = node.getLayoutConstraint();
		if (layout != null) {
			if (layout instanceof Location) {
				Location labelLocation = (Location) layout;
				Coordinate absoluteObjectPosition = NotationModelHelper.getAbsolutePNMLPositionObject(object);
				coord.setX(labelLocation.getX() - absoluteObjectPosition.getX());
				coord.setY(labelLocation.getY() - absoluteObjectPosition.getY());
			} 
		}

		return coord;
	}
	
	private static Coordinate getAbsolutePNMLPosition(org.eclipse.gmf.runtime.notation.Node node) {
		Coordinate coord = PnmlcoremodelFactory.eINSTANCE.createCoordinate();

		LayoutConstraint layout = node.getLayoutConstraint();
		if (layout != null) {
			if (layout instanceof Location) {
				Location labelLocation = (Location) layout;
				coord.setX(labelLocation.getX());
				coord.setY(labelLocation.getY());
			} 
		}

		return coord;
	}
	

}
