package org.pnml.tools.epnk.pnmlcoremodel.serialisation;

import java.util.HashMap;
import java.util.List;
import java.util.Vector;

import org.eclipse.core.runtime.Assert;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EClassifier;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;

// @generated NOT 
public class ExtendedPNMLMetaData {
	
	private HashMap<EStructuralFeature,List<PNMLFeatureElementMap>> feature2featureMapList;
	private HashMap<String,List<PNMLFeatureElementMap>> element2featureMapList;
	
	private HashMap<EStructuralFeature,List<PNMLFeatureAttributeMap>> feature2attributeList;
	private HashMap<String,List<PNMLFeatureAttributeMap>> attribute2featureList;
	private List<PNMLFeatureAttributeMap> attributes;
	
	private HashMap<EClass,EStructuralFeature> content2featureMap;
	
	// EK: New Map for mapping a objects type to an XML element;
	// Note that this still needs to be refined (right now, we
	// assume that the same XML element means the same in every
	// context (which is not realistic for different types and
	// for some types, it might even be unrealistic within the
	// same type.
	private HashMap<EClass,String> targetClass2element;
	private HashMap<String,IPNMLFactory> element2factory;
	
	// Standard features
	private HashMap<EStructuralFeature,EClass> standardFeature2class;
	private HashMap<EClass,EStructuralFeature> class2standardFeature;
	
	// Bundle feature mappings
	private HashMap<EStructuralFeature,String> bundleFeatures;


	public ExtendedPNMLMetaData() {
		feature2featureMapList = new HashMap<EStructuralFeature,List<PNMLFeatureElementMap>>();
		element2featureMapList = new HashMap<String,List<PNMLFeatureElementMap>>();
		
		feature2attributeList = new HashMap<EStructuralFeature,List<PNMLFeatureAttributeMap>>();
		attribute2featureList = new HashMap<String,List<PNMLFeatureAttributeMap>>();
		attributes = new Vector<PNMLFeatureAttributeMap>();
		
		content2featureMap = new HashMap<EClass,EStructuralFeature>();
		
		targetClass2element = new HashMap<EClass,String>();
		element2factory = new HashMap<String,IPNMLFactory>();
		
		standardFeature2class =  new HashMap<EStructuralFeature,EClass>();
		class2standardFeature = new HashMap<EClass,EStructuralFeature>();
		
		bundleFeatures = new HashMap<EStructuralFeature,String>();
	}

	public void add(EStructuralFeature feature, EClass container, EClass target, String element, String attribute, IPNMLFactory factory, boolean bundle) {
		if (bundle && feature != null && feature.getUpperBound() < 0 && element != null) {
			bundleFeatures.put(feature,element);
		}
		
		this.add(feature, container, target, element, attribute, factory);
		
	}
	
	public void add(EStructuralFeature feature, EClass container, EClass target, String element, String attribute, IPNMLFactory factory) {
		
		if (feature == null) {
			if (element != null && target != null) {
		     targetClass2element.put(target, element);
		     element2factory.put(element, factory);
		     // FIXME should be joint with the other case
		     List<PNMLFeatureElementMap> featureMapList = element2featureMapList.get(element);
		     if ( featureMapList == null) {
		    	 featureMapList = new Vector<PNMLFeatureElementMap>();
		    	 element2featureMapList.put(element, featureMapList);
		     }
		     featureMapList.add(new PNMLFeatureElementMap(feature,container,target,element,attribute,factory));
		     return;
		     // FIXME Note that in the case of an empty feature, we do not set the other
		     // mappings for now (as we are testing this). This can be improved by storing
		     // and checking for the right context.
			} else {
			   // this should not happen
			   Assert.isTrue(false);
			}
		}
		
		if (element != null || factory != null) {
			PNMLFeatureElementMap featureMap = new PNMLFeatureElementMap(feature,container,target,element,attribute,factory);

			List<PNMLFeatureElementMap> featureMapList =  feature2featureMapList.get(feature);
			if (featureMapList == null) {
				featureMapList = new Vector<PNMLFeatureElementMap>();
				feature2featureMapList.put(feature, featureMapList);
			}
			featureMapList.add(featureMap);

			featureMapList = element2featureMapList.get(element);
			if ( featureMapList == null) {
				featureMapList = new Vector<PNMLFeatureElementMap>();
				element2featureMapList.put(element, featureMapList);
			}
			featureMapList.add(new PNMLFeatureElementMap(feature,container,target,element,attribute,factory));
		} else {
			   standardFeature2class.put(feature, target);
			   class2standardFeature.put(container, feature);
	    }
		
	}
	
	public void addAttributeMapping(EStructuralFeature feature, EClass containerClass, String attributeName, IPNMLFactory factory) {
		PNMLFeatureAttributeMap feature2attributeMap = new PNMLFeatureAttributeMap(feature,containerClass,attributeName,factory);
		attributes.add(feature2attributeMap);
		
		List<PNMLFeatureAttributeMap> attributeList = feature2attributeList.get(feature);
		if (attributeList == null) {
			attributeList = new Vector<PNMLFeatureAttributeMap>();
			feature2attributeList.put(feature, attributeList);
		}
		attributeList.add(feature2attributeMap);	
		
		attributeList = attribute2featureList.get(attributeName);
		if (attributeList == null) {
			attributeList = new Vector<PNMLFeatureAttributeMap>();
			attribute2featureList.put(attributeName, attributeList);
		}
		attributeList.add(feature2attributeMap);	
		
	}
	
	public void addContentFeatureMapping(EClass clazz, EStructuralFeature feature) {
		// TODO this mapping is not yet considered, when saving the XML file;
		//      this feature should not yet be used.
		content2featureMap.put(clazz,feature);
	}

	
	public String getElement(EObject o, EStructuralFeature f) {
		List<PNMLFeatureElementMap> featureMapList = feature2featureMapList.get(f);
		if (featureMapList == null) {
			return null;
		}
		
		String result = null;
		for (PNMLFeatureElementMap featureMap : featureMapList) {
			EClass target = featureMap.getTarget();
			if (target == null || target.isInstance(o)) {
				result = featureMap.getElement();
				// FIXME up to now, we just take the last mapping. What we should use however,
				//       is the most specific one (and then, actually rather the first most
				//       specific one!
			}
		}
		return result;
	}

    public PNMLFeatureElementMap getFeatureElementMap(EObject container, String name, boolean isElement, IAttributeProvider provider) {
    	List<PNMLFeatureElementMap> featureMapList = element2featureMapList.get(name);
    	if (featureMapList == null) {
    		return null;
    	}
    	
    	PNMLFeatureElementMap result = null;
    	
    	for (PNMLFeatureElementMap featureMap: featureMapList) {
    		if ((featureMap.getContainer() == null || featureMap.getContainer().isInstance(container)) &&
    		    (featureMap.getFeature() == null || featureMap.getFeature().getContainerClass().isInstance(container)) ) {
    			String attribute = featureMap.getAttribute();
    			if (attribute == null || provider.getValue(attribute) != null) {
    				EStructuralFeature feature = featureMap.getFeature();
    				if (feature == null && container != null) {
    					feature = this.getStandardFeature(container.eClass());
    					EClass targetClass = featureMap.getTarget();
    					if (feature != null && (targetClass == null || targetClass.equals(feature.getEType()) || targetClass.getEAllSuperTypes().contains(feature.getEType()))) {
    						featureMap =
    							new PNMLFeatureElementMap(
    									feature,
    									featureMap.getContainer(),
    									featureMap.getTarget(),
    									featureMap.getElement(),
    									featureMap.getAttribute(),
    									featureMap.getFactory());
    						
    						// FIXME maybe we should use the standard feature only, if there is no other
    						//       "more suitable feature".
    					}
    				}
    				IPNMLFactory factory = featureMap.getFactory();
    				if (factory != null ) {
    					if (factory.canCreateObject(featureMap.getFeature(), container, name, attribute, provider)) {
    					// FIXME up to now, we just take the last mapping. What we should use however,
    					//       is the most specific one (and then, actually rather the first most
    					//       specific one!
    					result = featureMap;
    					// FIXME (see above) Now, we take the first mapping! Actually we should take the
    					//       first most specific mapping (whatever that precisely is)
    					return result;
    					}
    				} else {
    					// This checks whether the target could be generated by the standard factory of the
    					// respective package and would be of the correct type.
    					EClass targetClass = featureMap.getTarget();
    					EClassifier featureType =  feature.getEType();
    					if (feature != null && targetClass != null && 
    							featureType instanceof EClass &&
    							((EClass) featureType).isSuperTypeOf(targetClass)) {
    						result = featureMap;
    						return result;
    					}
    				}
    			}
    		}
    	}
    	
    	return result;
    	
    }
    
    public PNMLFeatureAttributeMap getFeature2AttributeMap(EObject o) {
    	PNMLFeatureAttributeMap result = null;
    	
    	for (PNMLFeatureAttributeMap featureAttributeMap: attributes) {
    		if (featureAttributeMap.getContainer().isInstance(o)) {
    			result = featureAttributeMap;
    		}
    	}
    	return result;
    	
    }
    
    public List<EStructuralFeature> getAttributeFeatures(EObject o) {
    	// TODO this is done over and over again for the same classes
    	//      this should be stored in a HasMap
    	Vector<EStructuralFeature> result = new Vector<EStructuralFeature>();
    	
    	for (PNMLFeatureAttributeMap featureAttributeMap: attributes) {
    		if (featureAttributeMap.getContainer().isInstance(o)) {
    			// TODO if a feature is more specific than another one,
    			//      only the more specific should go to this list!
    			result.add(featureAttributeMap.getFeature());
    		}
    	}
    	return result;
    }
    
    public List<PNMLFeatureAttributeMap> getFeatureAttributeMapList(EObject o) {
    	// TODO this is done over and over again for the same classes
    	//      this should be stored in a HasMap
    	Vector<PNMLFeatureAttributeMap> result = new Vector<PNMLFeatureAttributeMap>();
    	
    	for (PNMLFeatureAttributeMap featureAttributeMap: attributes) {
    		if (featureAttributeMap.getContainer().isInstance(o)) {
    			// TODO if a feature is more specific than another one,
    			//      only the more specific should go to this list!
    			result.add(featureAttributeMap);
    		}
    	}
    	return result;
    }
    
	public String getAttribute(EObject o, EStructuralFeature f) {
		List<PNMLFeatureAttributeMap> attributeList = feature2attributeList.get(f);
		if (attributeList == null) {
			return null;
		}
		
		String result = null;
		for (PNMLFeatureAttributeMap feature2attribute : attributeList) {
			EClass container = feature2attribute.getContainer();
			if (container == null || container.isInstance(o)) {
				result = feature2attribute.getAttributeName();
				// FIXME up to now, we just take the last mapping. What we should use however,
				//       is the most specific one (and then, actually rather the first most
				//       specific one!
			}
		}
		return result;
	}
	
	
	public void setAttribute(EObject o, String name, IAttributeProvider provider) {
		List<PNMLFeatureAttributeMap> attributeList = attribute2featureList.get(name);
		if (attributeList == null) {
			return;
		}

		PNMLFeatureAttributeMap useMap = null;
		for (PNMLFeatureAttributeMap feature2attribute : attributeList) {
			EClass container = feature2attribute.getContainer();
			if (container == null || container.isInstance(o)) {
				useMap = feature2attribute;
				// FIXME up to now, we just take the last mapping. What we should use however,
				//       is the most specific one (and then, actually rather the first most
				//       specific one!
			}
		}
		
		o.eSet(useMap.getFeature(), useMap.getFactory().createAttributeObject(o, name, provider));
		
	}
	
	public EStructuralFeature getContentFeature(EClass clazz) {
		return content2featureMap.get(clazz);
	}

	
	public String getClassElement(EClass clazz) {
		return targetClass2element.get(clazz);
	}
	
	public IPNMLFactory getElementFactory(String element) {
		return element2factory.get(element);
	}
	
	public boolean isStandardFeature(EStructuralFeature feature) {
		return standardFeature2class.containsKey(feature);
	}
	
	
	// TODO up to now this is not used at all.
	public EClass getStandardFeatureClass(EStructuralFeature feature) {
		return standardFeature2class.get(feature);
	}
	
	public EStructuralFeature getStandardFeature(EClass clazz) {
	    Vector<EClass> inspectClasses = new Vector<EClass>();
	    inspectClasses.add(clazz);
	    EStructuralFeature feature = null;
	    
	    while(feature == null && inspectClasses.size() > 0) {
	    	// FIXME this could be implemented a bit more efficiently
	    	//       and there might be problems in case of multiple
	    	//       inheritance.
	    	EClass c = inspectClasses.firstElement();
	    	inspectClasses.remove(c);
	    	feature = class2standardFeature.get(c);
	    	inspectClasses.addAll(c.getESuperTypes());
	    }
	    
	    return feature;
	}
	
	public String getBundleFeatureElement(EStructuralFeature feature) {
		return this.bundleFeatures.get(feature);
	}
	
}
